==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/INVESTMENTPLANNINGSCENARIOID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVESTMENTPLANNINGSCENARIOID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="INVESTMENTPLANNINGSCENARIOID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SCENARIOID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INVESTMENTPLANNINGID" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVESTMENTPLANNINGSCENARIOID_Type", propOrder = {
    "scenarioid",
    "investmentplanningid"
})
public class INVESTMENTPLANNINGSCENARIOID_Type {

    @XmlElement(name = "SCENARIOID")
    protected STANDARDENTITYID_Type scenarioid;
    @XmlElement(name = "INVESTMENTPLANNINGID")
    protected STANDARDENTITYID_Type investmentplanningid;

    /**
     * Gets the value of the scenarioid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getSCENARIOID() {
        return scenarioid;
    }

    /**
     * Sets the value of the scenarioid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setSCENARIOID(STANDARDENTITYID_Type value) {
        this.scenarioid = value;
    }

    /**
     * Gets the value of the investmentplanningid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getINVESTMENTPLANNINGID() {
        return investmentplanningid;
    }

    /**
     * Sets the value of the investmentplanningid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setINVESTMENTPLANNINGID(STANDARDENTITYID_Type value) {
        this.investmentplanningid = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_fields/INVESTMENTPLANNINGSCENARIOID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVESTMENTPLANNINGSCENARIOID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INVESTMENTPLANNINGSCENARIOID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCENARIOID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVESTMENTPLANNINGID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVESTMENTPLANNINGSCENARIOID_Type", propOrder = {
    "scenarioid",
    "investmentplanningid"
})
public class INVESTMENTPLANNINGSCENARIOID_Type {

    @XmlElement(name = "SCENARIOID")
    protected STANDARDENTITYID_Type scenarioid;
    @XmlElement(name = "INVESTMENTPLANNINGID")
    protected STANDARDENTITYID_Type investmentplanningid;

    /**
     * Gets the value of the scenarioid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getSCENARIOID() {
        return scenarioid;
    }

    /**
     * Sets the value of the scenarioid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setSCENARIOID(STANDARDENTITYID_Type value) {
        this.scenarioid = value;
    }

    /**
     * Gets the value of the investmentplanningid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getINVESTMENTPLANNINGID() {
        return investmentplanningid;
    }

    /**
     * Sets the value of the investmentplanningid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setINVESTMENTPLANNINGID(STANDARDENTITYID_Type value) {
        this.investmentplanningid = value;
    }

}
